@@ -5,7 +5,19 @@ import time
 
 import redis
 
-from ._internal import *
+from ._internal import (
+    ACTIVE,
+    ERROR,
+    QUEUED,
+    SCHEDULED,
+    g,
+    gen_id,
+    gen_unique_id,
+    get_timestamp,
+    import_attribute,
+    serialize_func_name,
+    serialize_retry_method,
+)
 from .exceptions import QueueFullException, TaskImportError, TaskNotFound
 from .runner import get_runner_class
 
@@ -29,6 +41,7 @@ class Task:
         retry_on=None,
         retry_method=None,
         max_queue_size=None,
+        max_stored_executions=None,
         runner_class=None,
         # internal variables
         _data=None,
@@ -83,6 +96,11 @@ class Task:
         if max_queue_size is None:
             max_queue_size = getattr(func, "_task_max_queue_size", None)
 
+        if max_stored_executions is None:
+            max_stored_executions = getattr(
+                func, "_task_max_stored_executions", None
+            )
+
         if runner_class is None:
             runner_class = getattr(func, "_task_runner_class", None)
 
@@ -129,6 +147,8 @@ class Task:
                 ]
         if max_queue_size:
             task["max_queue_size"] = max_queue_size
+        if max_stored_executions is not None:
+            task["max_stored_executions"] = max_stored_executions
         if runner_class:
             serialized_runner_class = serialize_func_name(runner_class)
             task["runner_class"] = serialized_runner_class
@@ -225,6 +245,10 @@ class Task:
             self._func = import_attribute(self.serialized_func)
         return self._func
 
+    @property
+    def max_stored_executions(self):
+        return self._data.get("max_stored_executions")
+
     @property
     def serialized_runner_class(self):
         return self._data.get("runner_class")
@@ -546,11 +570,13 @@ class Task:
         """
         pipeline = self.tiger.connection.pipeline()
         pipeline.exists(self.tiger._key("task", self.id))
-        pipeline.llen(self.tiger._key("task", self.id, "executions"))
-        exists, n_executions = pipeline.execute()
+        pipeline.get(self.tiger._key("task", self.id, "executions_count"))
+
+        exists, executions_count = pipeline.execute()
         if not exists:
             raise TaskNotFound("Task {} not found.".format(self.id))
-        return n_executions
+
+        return int(executions_count or 0)
 
     def retry(self):
         """
