@@ -1,10 +1,14 @@
 import errno
 import fcntl
+import hashlib
+import json
+import os
 import random
 import select
 import signal
 import socket
 import sys
+import threading
 import time
 import traceback
 import uuid
@@ -14,10 +18,27 @@ from typing import List, Set
 
 from redis.exceptions import LockError
 
-from ._internal import *
-from .exceptions import RetryException, TaskNotFound
+from ._internal import (
+    ACTIVE,
+    ERROR,
+    QUEUED,
+    SCHEDULED,
+    dotted_parts,
+    g,
+    g_fork_lock,
+    gen_unique_id,
+    import_attribute,
+    queue_matches,
+    serialize_func_name,
+    serialize_retry_method,
+)
+from .exceptions import (
+    RetryException,
+    StopRetry,
+    TaskImportError,
+    TaskNotFound,
+)
 from .redis_semaphore import Semaphore
-from .retry import *
 from .runner import get_runner_class
 from .stats import StatsThread
 from .task import Task
@@ -390,9 +411,6 @@ class Worker:
 
         execution["time_started"] = time.time()
 
-        exc = None
-        exc_info = None
-
         try:
             func = tasks[0].func
 
@@ -1168,11 +1186,18 @@ class Worker:
         serialized_execution = json.dumps(execution)
 
         for task in tasks:
-            pipeline = self.connection.pipeline()
-            pipeline.incr(self._key("task", task.id, "executions_count"))
-            pipeline.rpush(
-                self._key("task", task.id, "executions"), serialized_execution
+            executions_key = self._key("task", task.id, "executions")
+            executions_count_key = self._key(
+                "task", task.id, "executions_count"
             )
+
+            pipeline = self.connection.pipeline()
+            pipeline.incr(executions_count_key)
+            pipeline.rpush(executions_key, serialized_execution)
+
+            if task.max_stored_executions:
+                pipeline.ltrim(executions_key, -task.max_stored_executions, -1)
+
             pipeline.execute()
 
     def run(self, once=False, force_once=False):
@@ -1240,7 +1265,7 @@ class Worker:
         except KeyboardInterrupt:
             pass
 
-        except Exception as e:
+        except Exception:
             self.log.exception(event="exception")
             raise
 
