@@ -7,7 +7,7 @@ import os
 DELAY = 0.4
 
 # Redis database number which will be wiped and used for the tests
-TEST_DB = int(os.environ.get('REDIS_DB', 7))
+TEST_DB = int(os.environ.get("REDIS_DB", 7))
 
 # Redis hostname
-REDIS_HOST = os.environ.get('REDIS_HOST', 'localhost')
+REDIS_HOST = os.environ.get("REDIS_HOST", "localhost")
